<?php

add_action( 'load-post-new.php', 'ideax_disable_admin_idea_creation' );
add_action( 'load-post.php', 'ideax_disable_admin_idea_editing' );

add_action( 'admin_notices', 'ideax_update_status_terms_notice' );

// Admin Scripts
add_action( 'admin_enqueue_scripts', 'ideax_add_admin_scripts', 10 );

// Admin Styles
add_action( 'admin_print_styles', 'ideax_admin_styles' );


/**
 * See if any ideas exist. Detect first activation.
 */
function ideax_first_run_check() {

	$ideas = get_posts( array( 'post_type' => IDEAX_PTYPE, 'posts_per_page' => 1 ) );

	if ( empty( $ideas ) )
		return true;

	return false;
}


/**
 * Adds styles for admin icons
 */
function ideax_admin_styles() {
	appthemes_menu_sprite_css( array(
		'#toplevel_page_app-dashboard',
		'#adminmenu #menu-posts-idea',
	) );
}


/**
 * Prevents contributors from adding new ideas on the backend
 */
function ideax_disable_admin_idea_creation() {
	if ( current_user_can( 'edit_others_ideas' ) )
		return;

	if ( IDEAX_PTYPE != @$_GET['post_type'] )
		return;

	wp_redirect( ideax_get_add_idea_url() );
	exit;
}


/**
 * Prevents contributors from editing new ideas on the backend
 */
function ideax_disable_admin_idea_editing() {
	if ( current_user_can( 'edit_others_ideas' ) )
		return;

	if ( 'edit' != @$_GET['action'] )
		return;

	$post_id = (int) @$_GET['post'];

	if ( IDEAX_PTYPE != get_post_type( $post_id ) )
		return;

	wp_redirect( ideax_get_idea_edit_url( $post_id ) );
	exit;
}


/**
 * Enqueue admin scripts
 */
function ideax_add_admin_scripts( $hook ) {
	global $post;

	// selective load
	$pages = array ( 'edit.php', 'post.php', 'post-new.php' );

 	if ( ! in_array( $hook, $pages ) || ( isset( $post ) && IDEAX_PTYPE != $post->post_type ) )
		return;

	wp_enqueue_script( 'validate' );
	wp_enqueue_script( 'validate-lang' );

	wp_enqueue_script(
		'ideax-admin-idea-edit',
		get_template_directory_uri() . '/includes/admin/scripts/idea-edit.js',
		array( 'validate' ),
		IDEAX_VERSION,
		true
	);

	wp_localize_script( 'ideax-admin-idea-edit', 'IDEAX_admin_l18n', array(
		'user_admin' => current_user_can( 'manage_options' ),
		'idea_type' => IDEAX_PTYPE,
		'idea_category' => IDEAX_CATEGORY,
		'idea_status' => IDEAX_STATUS,
		'post_type' => ( isset( $post->post_type ) ? $post->post_type : '' ),
		'validate_fields'	=> (bool) ( isset( $_GET['action'] ) && 'edit' == $_GET['action'] ),
		'message_no_status' => __( 'Warning: This Idea will not be published until you set a valid status.', APP_TD ),
		'message_no_category' => __( 'Warning: This Idea will not be published until you set a valid category.', APP_TD ),
	) );

}


/**
 * Reminder for users to update the settings for new/edited status
 */
function ideax_update_status_terms_notice() {
	global $current_screen;

	if ( IDEAX_STATUS != $current_screen->taxonomy )
		return;

	echo scb_admin_notice( sprintf ( __( '<strong>Note:</strong> If you add/edit a status equivalent to \'Open\' (i.e: Under Review), don\'t forget to add the related slug on the <a href="%s">settings page</a>.', APP_TD ), 'admin.php?page=app-settings' ) );
}
