<?php

// Admin listings functions

add_filter( 'manage_edit-' . IDEAX_PTYPE . '_columns', 'ideax_manage_columns', 11 );
add_action( 'manage_' . IDEAX_PTYPE . '_posts_custom_column', 'ideax_add_column_data', 10, 2 );
add_filter( 'manage_edit-' . IDEAX_PTYPE . '_sortable_columns', 'ideax_columns_sort' );

add_filter( 'request', 'ideax_column_orderby' );
add_action( 'restrict_manage_posts', 'ideax_add_filters' );
add_filter( 'parse_query', 'ideax_filter_by_taxonomy' );


/**
 * Sets columns for ideas listings on edit.php page
 *
 * @param array $columns
 *
 * @return array
 */
function ideax_manage_columns( $columns ) {

	$columns_new = array(
		'cb' => $columns['cb'],
		'title' => __( 'Title', APP_TD ),
		'author' => __( 'Author', APP_TD ),
		'taxonomy-' . IDEAX_CATEGORY => __( 'Categories', APP_TD ),
		'taxonomy-' . IDEAX_STATUS => __( 'Status', APP_TD ),
		'taxonomy-' . IDEAX_TAG => __( 'Tags', APP_TD ),
		'votes' => __( 'Votes', APP_TD ),
		'comments' => '<span class="vers"><div title="' . esc_attr__( 'Comments', APP_TD ) . '" class="comment-grey-bubble"></div></span>',
		'date' => __( 'Date', APP_TD ),
	);
	$columns = $columns_new;

	return $columns;
}


/**
 * Registers custom columns as sortable
 *
 * @param array $columns
 *
 * @return array
 */
function ideax_columns_sort( $columns ) {
	$columns['votes'] = 'votes';

	return $columns;
}


/**
 * Sets how the columns sorting should work
 *
 * @param array $vars
 *
 * @return array
 */
function ideax_column_orderby( $vars ) {
	if ( isset( $vars['orderby'] ) && 'votes' == $vars['orderby'] ) {
		$vars = array_merge( $vars, array(
			'meta_key' => '_ideax_idea_total_votes',
			'orderby' => 'meta_value_num'
		) );
	}

	return $vars;
}


/**
 * Displays the values for each idea column on edit.php page
 *
 * @param string $column
 * @param int $post_id
 *
 * @return void
 */
function ideax_add_column_data( $column, $post_id ) {
	switch ( $column ) {
		case 'votes' :
			echo number_format_i18n( intval( $total_votes = get_post_meta( $post_id, '_ideax_idea_total_votes', true ) ) );
			break;
	}
}


/**
 * Adds the drop-down filter on edit.php page
 *
 * @return void
 */
function ideax_add_filters() {
	global $typenow, $wp_query;

	$taxonomies = array( IDEAX_CATEGORY, IDEAX_STATUS );

	if ( $typenow == IDEAX_PTYPE ) {
		foreach ( $taxonomies as $taxonomy ) {
			$selected = isset( $_GET[ $taxonomy ] ) ? $_GET[ $taxonomy ] : '';
			$status_taxonomy = get_taxonomy( $taxonomy );
			wp_dropdown_categories( array(
				'show_option_all' => sprintf( __( 'Show All %s', APP_TD ), $status_taxonomy->labels->menu_name ),
				'taxonomy'        => $taxonomy,
				'name'            => $taxonomy,
				'orderby'         => 'name',
				'selected'        => $selected,
				'hierarchical'    => true,
				'depth'           => 3,
				'show_count'      => true,
				'hide_empty'      => true,
			) );
		}
	}
}


/**
 * Handles the filtering by taxonomy on edit.php page
 *
 * @param object $query
 *
 * @return object
 */
function ideax_filter_by_taxonomy( $query ) {
	global $pagenow, $typenow;

	if ( ! is_admin() || $pagenow != 'edit.php' || $typenow != IDEAX_PTYPE ) {
		return $query;
	}

	$taxonomies = get_object_taxonomies( $typenow, 'names' );

	foreach ( $taxonomies as $tax_name ) {
		if ( ! empty( $query->query_vars[ $tax_name ] ) && is_numeric( $query->query_vars[ $tax_name ] ) ) {
			$term = get_term_by( 'id', $query->query_vars[ $tax_name ], $tax_name );
			if ( $term ) {
				$query->query_vars[ $tax_name ] = $term->slug;
			}
		}
	}

	return $query;
}
