<?php

// Admin single page functions / Metaboxes

// add_action( 'admin_init', 'ideax_hide_meta' ); // show everything
//add_action( 'admin_init', 'ideax_init_status_walker' );
add_action( 'pre_post_update', 'ideax_status_change', 10, 3 );

//add_filter( 'wp_terms_checklist_args', 'ideax_status_checklist', 10, 2 );
add_filter( 'wp_insert_post_data' , 'ideax_pre_publish_idea' , 10, 2 );

/**
 * Metaboxes
 *
 */

class IDEAX_Votes_Meta extends APP_Meta_Box {

	private $votes = 0;

	public function __construct() {

		if ( ! empty( $_POST['post_ID'] ) ) {
			$post_id = (int) $_POST['post_ID'];
		} elseif( isset( $_GET['post'] ) ) {
			$post_id = (int) $_GET['post'];
		} elseif ( isset( $_POST['post_ID'] ) ) {
			$post_id = (int) $_GET['post_ID'];
		} else {
			return;
		}

		$this->votes = get_the_votes( $post_id );

		if ( ( ! empty( $_GET['action'] ) && 'edit' != $_GET['action'] ) || ! current_user_can( 'edit_others_posts' ) )
			return;

		add_action( 'save_post', array( $this, 'reset_votes' ), 11, 2 );

		parent::__construct( 'idea-votes', __( 'Votes', APP_TD ), IDEAX_PTYPE, 'side', 'high' );
	}

	public function before_form( $post ) {
		echo html( 'div', array( 'class' => 'idea-votes' ), html( 'p', $this->votes ) );
	}

	public function form() {
		return array(
			array(
				'title' => __( 'Reset Votes', APP_TD ),
				'type' => 'checkbox',
				'name' => 'reset_votes',
				'desc' => __( 'Yes', APP_TD ),
			),
		);

	}

	public function after_form( $post ) {
		echo html( 'p', array(
				'class' => 'howto'
			), __( 'Check \'Yes\' to reset votes on \'Update\'.', APP_TD ) );
	}

	public function reset_votes( $post_id, $post ) {
		if ( isset( $_POST['reset_votes'] ) ) {
			ideax_reset_votes( $post_id );
		}
	}

}

class IDEAX_Idea_Official_Response_Meta extends APP_Meta_Box {

	private static $field;

	public function __construct() {
		self::$field = '_idea_official_response';

		parent::__construct( 'idea-official-response', __( 'Official Response', APP_TD ), IDEAX_PTYPE, 'advanced', 'default' );
	}

	public function admin_enqueue_scripts() {
		// add tinyMCE editor styles
		add_editor_style( '/styles/editor-style.css' );
	}

	function display( $post ) {
		echo html( 'p', array(
				'class' => ''
			), __( 'Appears publicly below the idea description. Should be used when changing "Open" status.', APP_TD ) );

		wp_editor(
			get_post_meta( $post->ID, self::$field, true ),
			self::$field,
			array(
				'media_buttons' => false,
				'textarea_name' => self::$field,
				'textarea_rows' => 10,
				'tabindex' => '2',
				'editor_css' => '',
				'editor_class' => '',
				'teeny' => false,
				'tinymce' => true,
				'quicktags' => array( 'buttons' => 'strong,em,link,block,ul,ol,li,code' )
			)
		);

	}

	public function before_save( $post_data, $post_id ) {
		if ( isset( $_POST[ self::$field ] ) ) {
			$post_data[ self::$field ] = $_POST[ self::$field ];
		}

		return $post_data;
	}

}

class IDEAX_Idea_Internal_Notes extends APP_Meta_Box {

	private static $field;

	public function __construct() {
		self::$field = '_idea_notes';

		parent::__construct( 'idea-internal-notes', __( 'Internal Notes', APP_TD ), IDEAX_PTYPE, 'advanced', 'default' );
	}

	public function admin_enqueue_scripts() {
		// add tinyMCE editor styles
		add_editor_style( '/styles/editor-style.css' );
	}

	function display( $post ) {
		echo html( 'p', array(
				'class' => ''
			), __( 'Does not appear publicly. Used for internal company communication only.', APP_TD ) );

		wp_editor(
			get_post_meta( $post->ID, self::$field, true ),
			self::$field,
			array(
				'media_buttons' => false,
				'textarea_name' => self::$field,
				'textarea_rows' => 10,
				'tabindex' => '2',
				'editor_css' => '',
				'editor_class' => '',
				'teeny' => false,
				'tinymce' => true,
				'quicktags' => array( 'buttons' => 'strong,em,link,block,ul,ol,li,code' )
			)
		);
	}

	public function before_save( $post_data, $post_id ) {
		if ( isset( $_POST[ self::$field ] ) ) {
			$post_data[ self::$field ] = $_POST[ self::$field ];
		}

		return $post_data;
	}

}


// don't publish posts while the category and status are not selected
function ideax_pre_publish_idea( $data, $postarr ) {
	if ( IDEAX_PTYPE == $data['post_type'] && isset( $postarr['post_ID'] ) ) {
		$post_id = $postarr['post_ID'];
		if ( 'publish' == $data['post_status'] && ( isset( $_GET['post'] ) || isset( $_POST['post_ID'] ) ) ) {
			if ( 1 === count( $postarr['tax_input'][ IDEAX_CATEGORY ] ) ) {
				$data['post_status'] = 'draft';
			}
		}
	}

	return $data;
}

// check for status taxonomy changes and notify idea owner if it changes
function ideax_status_change( $post_id ) {
	if ( $curr_status = get_the_idea_terms( $post_id, IDEAX_STATUS ) ) {
		if ( isset( $_POST['tax_input'][ IDEAX_STATUS ][1] ) && ( $_POST['tax_input'][ IDEAX_STATUS ][1] != $curr_status->term_id ) ) {
			$new_status = $_POST['tax_input'][ IDEAX_STATUS ][1];
			$post = get_post( $post_id );
			ideax_ideas_status_change_email( $post, $curr_status->term_id, $new_status );
		}
	}
}

/**
 * Hides a list of metaboxes
 */
function ideax_hide_meta() {
	$remove_boxes = array( 'postexcerpt', 'revisionsdiv', 'postcustom', 'authordiv', 'commentstatusdiv' );
	foreach( $remove_boxes as $id ) {
		remove_meta_box( $id, IDEAX_PTYPE, 'normal' );
	}
	remove_meta_box( 'postimagediv', IDEAX_PTYPE, 'side' );
}

/**
 * Override the 'Walker_Category_Checklist' method, 'start_el', to replace checkboxes with radio buttons
 */
function ideax_init_status_walker() {

	class IDEAX_Status_Walker extends Walker_Category_Checklist {

		private $inline_edit = false;

		function __construct( $post_id, $taxonomy ) {
			$this->inline_edit = (bool) ! $post_id;
		}

		function start_el( &$output, $category, $depth = 0, $args = array(), $id = 0 ) {

			extract( $args );
			if ( empty( $taxonomy ) )
				$taxonomy = 'category';

			if ( $taxonomy == 'category' ) {
				$name = 'post_category';
			} else {
				$name = 'tax_input[' . $taxonomy . ']';
			}

			$class = in_array( $category->term_id, $popular_cats ) ? ' class="popular-category"' : '';

			$output .= "\n<li id='{$taxonomy}-{$category->term_id}'$class>";
			$output .= '<label class="selectit">';
			$output .= '<input value="' . $category->term_id . '" type="radio" name="'.$name.'[]" id="in-' . $taxonomy . '-' . $category->term_id . '"';
			$output .= checked( in_array( $category->term_id, $selected_cats ), true, false ) . disabled( empty( $args['disabled'] ), false, false ) . ' /> ';
			$output .= esc_html( apply_filters( 'the_category', $category->name ) );
			$output .= '</label>';
		}
	}

}

/**
 * Hook into 'wp_terms_checklist_args' to override the category Walker and display radios buttons instead of checkboxes
 */
function ideax_status_checklist( $args, $post_id ) {
	global $post;

	if ( is_admin() && IDEAX_PTYPE == $post->post_type && ( IDEAX_CATEGORY == $args['taxonomy'] || IDEAX_STATUS == $args['taxonomy'] ) ) {
		$args['walker'] = new IDEAX_Status_Walker( $post_id, $args['taxonomy'] );
		$args['checked_ontop'] = false;
	}

	return $args;
}
