<?php
/**
 * Install script to insert default data.
 */


// Installation procedures
add_action( 'appthemes_first_run', 'ideax_init_settings' );
add_action( 'appthemes_first_run', 'ideax_init_menu' );
add_action( 'appthemes_first_run', 'ideax_init_widgets' );
add_action( 'appthemes_first_run', 'ideax_init_content' );


/**
 * Initialize settings
 */
function ideax_init_settings() {

	if ( ! ideax_first_run_check() )
		return;

	update_option( 'show_on_front', 'page' );
	update_option( 'page_on_front', IDEAX_Idea_Front::get_id() );
	update_option( 'page_for_posts', IDEAX_Blog_Archive::get_id() );

	if ( ! get_option( 'permalink_structure' ) )
		update_option( 'permalink_structure', '/%postname%/' );

	update_option( 'users_can_register', 1 );

}


/**
 * Add default content if no content exists
 */
function ideax_init_content() {
	// Deliberately left untranslated

	if ( ! ideax_first_run_check() )
		return;

	$cat = appthemes_maybe_insert_term( 'Product Name 1', IDEAX_CATEGORY );
	appthemes_maybe_insert_term( 'Product Name 2', IDEAX_CATEGORY );
	appthemes_maybe_insert_term( 'Product Name 3', IDEAX_CATEGORY );
	appthemes_maybe_insert_term( 'Product Name 4', IDEAX_CATEGORY );

	$status = appthemes_maybe_insert_term( 'Open', IDEAX_STATUS );
	appthemes_maybe_insert_term( 'Under Review', IDEAX_STATUS );
	appthemes_maybe_insert_term( 'Accepted', IDEAX_STATUS );
	appthemes_maybe_insert_term( 'In Progress', IDEAX_STATUS );
	appthemes_maybe_insert_term( 'Declined', IDEAX_STATUS );
	appthemes_maybe_insert_term( 'Closed', IDEAX_STATUS );

	$user_id = username_exists( 'ideaman' );
	if ( ! $user_id ) {
		$user_id = wp_insert_user( array(
			'user_login' => 'ideaman',
			'user_email' => 'demo@appthemes.com',
			'display_name' => 'ideaman',
			'first_name' => 'Idea',
			'last_name' => 'Man',
			'user_pass' => wp_generate_password(),
			'role' => 'contributor'
		) );
		// reset the dummy user votes
		ideax_reset_user_votes( $user_id );
	}

	// reset admin user votes
	ideax_reset_user_votes(1);

	$idea_id = wp_insert_post( array(
		'post_type' => IDEAX_PTYPE,
		'post_status' => 'publish',
		'post_author' => $user_id,
		'post_title' => 'This is a sample idea. You can delete me safely.',
		'post_content' => 'I would love to be able to post my own Ideas to your website. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec at est odio, vel tincidunt elit. Mauris in felis ut velit ultricies interdum. Nulla dapibus neque non tellus imperdiet tincidunt. Sed rutrum elit sed felis consectetur in euismod nunc volutpat. Praesent ac urna magna, et laoreet elit. Praesent ornare gravida varius.',
		'tax_input' => array(
			IDEAX_CATEGORY => array( $cat['term_id'] ),
			IDEAX_TAG => 'ideas',
			IDEAX_STATUS => array( $status['term_id'] )
		)
	) );

	update_post_meta( $idea_id, '_idea_official_response', "This idea looks great. We'll try and get it implemented in our next release cycle." );
	update_post_meta( $idea_id, '_ideax_idea_total_votes', 2 );


	// insert the voters into the "who voted" sidebar widget
	$voter_data = array(
		'users' => array(
			1 => array( 'votes' => 1, 'name' => 'admin', 'added' => time() ),
			$user_id => array( 'votes' => 1, 'name' => 'ideaman', 'added' => time() ),
		),
		'last_updated' => time()
	);
	update_post_meta( $idea_id, '_ideax_post_votes', $voter_data );


	$time = current_time( 'mysql' );

	$data = array(
		'comment_post_ID' => $idea_id,
		'comment_author' => 'AppThemes',
		'comment_author_email' => 'demo@appthemes.com',
		'comment_author_url' => 'http://www.appthemes.com',
		'comment_content' => "I was going to suggest this idea myself. What a difference this would make. I've voted it up already!",
		'comment_type' => '',
		'comment_parent' => 0,
		'user_id' => $user_id,
		'comment_author_IP' => '127.0.0.1',
		'comment_agent' => 'Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.10) Gecko/2009042316 Firefox/3.0.10 (.NET CLR 3.5.30729)',
		'comment_date' => $time,
		'comment_approved' => 1,
	);

	wp_insert_comment( $data );

}

/**
 * Initialize menus
 */
function ideax_init_menu() {
	global $ideax_options;

	if ( ! ideax_first_run_check() )
		return;

	if ( has_nav_menu( 'header' ) )
		return;

	$menu_id = wp_create_nav_menu( __( 'Header', APP_TD ) );
	if ( is_wp_error( $menu_id ) ) {
		return;
	}

	// add home
	wp_update_nav_menu_item( $menu_id, 0, array(
		'menu-item-object' => 'page',
		'menu-item-title' => __( 'Home', APP_TD ),
		'menu-item-url' => home_url('/'),
		'menu-item-status' => 'publish',
	) );

	// add ideas
	wp_update_nav_menu_item( $menu_id, 0, array(
		'menu-item-object' => 'page',
		'menu-item-title' => __( 'Ideas', APP_TD ),
		'menu-item-url' => home_url( '/' . $ideax_options->ideas_permalink ),
		'menu-item-status' => 'publish'
	) );

	$page_ids = array(
		IDEAX_Idea_Add::get_id(),
		IDEAX_Blog_Archive::get_id(),
		IDEAX_Contact::get_id(),
	);

	foreach ( $page_ids as $page_id ) {
		$page = get_post( $page_id );

		if ( ! $page )
			continue;

		wp_update_nav_menu_item( $menu_id, 0, array(
			'menu-item-type' => 'post_type',
			'menu-item-object' => 'page',
			'menu-item-object-id' => $page_id,
			'menu-item-title' => $page->post_title,
			'menu-item-url' => get_permalink( $page ),
			'menu-item-status' => 'publish',
		) );
	}

	$locations = get_theme_mod( 'nav_menu_locations' );
	$locations['header'] = $menu_id;
	$locations['footer'] = $menu_id;
	set_theme_mod( 'nav_menu_locations', $locations );
}


/**
 * Initialize widgets
 */
function ideax_init_widgets() {

	if ( ! ideax_first_run_check() )
		return;

	$sidebars_widgets = array(
		// Main
		'main' => array(
			'ideax-submit-idea-button' => array(
				'label' => __( 'Submit Your Idea', APP_TD ),
			),
			'ideax-category-list' => array(
				'title' => __( 'Categories', APP_TD ),
				'count' => 0,
			),
			'ideax-recent-ideas' => array(
				'title' => __( 'Recent Ideas', APP_TD ),
				'number' => 5,
			),
			'ideax-popular-ideas' => array(
				'title' => __( 'Popular Ideas', APP_TD ),
				'number' => 5,
			),
		),
		// Header
		'header' => array(
			'ideax-stat-counter' => array(),
		),
		// Single Idea
		'single-idea' => array(
			'ideax-quick-info' => array(
				'title' => __( 'Quick Info', APP_TD ),
			),
			'ideax-votes' => array(
				'title' => __( 'Voters', APP_TD ),
				'number' => 5,
			),
			'ideax-recent-ideas' => array(
				'title' => __( 'Recent Ideas', APP_TD ),
				'number' => 5,
			),
		),
		// Search Idea
		'search-idea' => array(
			'ideax-submit-idea-button' => array(
				'label' => __( 'Submit Your Idea', APP_TD ),
			),
			'ideax-category-list' => array(
				'title' => __( 'Categories', APP_TD ),
				'count' => 0,
			),
			'ideax-recent-ideas' => array(
				'title' => __( 'Recent Ideas', APP_TD ),
				'number' => 5,
			),
			'ideax-popular-ideas' => array(
				'title' => __( 'Popular Ideas', APP_TD ),
				'number' => 5,
			),
		),
		// Add Idea
		'add-idea' => array(
			'ideax-submit-idea-button' => array(
				'label' => __( 'Submit Your Idea', APP_TD ),
			),
			'ideax-category-list' => array(
				'title' => __( 'Categories', APP_TD ),
				'count' => 0,
			),
			'ideax-recent-ideas' => array(
				'title' => __( 'Recent Ideas', APP_TD ),
				'number' => 5,
			),
			'ideax-popular-ideas' => array(
				'title' => __( 'Popular Ideas', APP_TD ),
				'number' => 5,
			),
		),
		// Page
		'page' => array(
			'ideax-submit-idea-button' => array(
				'label' => __( 'Submit Your Idea', APP_TD ),
			),
			'ideax-category-list' => array(
				'title' => __( 'Categories', APP_TD ),
				'count' => 0,
			),
			'ideax-recent-ideas' => array(
				'title' => __( 'Recent Ideas', APP_TD ),
				'number' => 5,
			),
			'ideax-popular-ideas' => array(
				'title' => __( 'Popular Ideas', APP_TD ),
				'number' => 5,
			),
		),
		// Blog Page
		'post' => array(
			'categories' => array(
				'title' => __( 'Categories', APP_TD ),
				'dropdown' => 0,
				'count' => 0,
				'hierarchical' => 0,
			),
			'recent-posts' => array(
				'title' => __( 'Recent Posts', APP_TD ),
				'number' => 10,
				'show_date' => 0,
			),
			'recent-comments' => array(
				'title' => __( 'Recent Comments', APP_TD ),
				'number' => 10,
			),
		),
		// Single Post
		'single' => array(
			'categories' => array(
				'title' => __( 'Categories', APP_TD ),
				'dropdown' => 0,
				'count' => 0,
				'hierarchical' => 0,
			),
			'recent-posts' => array(
				'title' => __( 'Recent Posts', APP_TD ),
				'number' => 10,
				'show_date' => 0,
			),
			'recent-comments' => array(
				'title' => __( 'Recent Comments', APP_TD ),
				'number' => 10,
			),
		),
		// Footer Column 1
		'footer-col-1' => array(
			'ideax-popular-ideas' => array(
				'title' => __( 'Popular Ideas', APP_TD ),
				'number' => 5,
			),
		),
		// Footer Column 2
		'footer-col-2' => array(
			'ideax-recent-ideas' => array(
				'title' => __( 'Recent Ideas', APP_TD ),
				'number' => 5,
			),
		),
		// Footer Column 3
		'footer-col-3' => array(
			'ideax-recent-comments' => array(
				'title' => __( 'Recent Responses', APP_TD ),
				'number' => 5,
			),
		),
	);

	appthemes_install_widgets( $sidebars_widgets );
}

