<?php

// Admin settings page

class IDEAX_Settings_Admin extends APP_Tabs_Page {

	protected $permalink_sections;
	protected $permalink_options;

	function setup() {
		$this->textdomain = APP_TD;

		$this->args = array(
			'page_title' => __( 'Ideas Settings', APP_TD ),
			'menu_title' => __( 'Settings', APP_TD ),
			'page_slug' => 'app-settings',
			'parent' => 'app-dashboard',
			'screen_icon' => 'options-general',
			'admin_action_priority' => 10,
		);

		add_action( 'admin_init', array( $this, 'init_integrated_options' ), 10 );
		add_action( 'admin_init', array( $this, 'maybe_reset_all_votes' ) );
		add_action( 'option_ideax_options', array( $this, 'clear_reset_votes' ) );
	}

	public static function email_markup_for( $option ) {

		$available_markup = array(
			'%ideatitle%'  => __( 'prints out the idea title', APP_TD ),
			'%ideaurl%'    => __( 'prints out the idea url', APP_TD ),
			'%authorname%' => __( 'prints out the author name', APP_TD ),
			'%siteurl%'    => __( 'prints out your website url', APP_TD ),
			'%sitename%'   => __( 'prints out your site name', APP_TD ),
			'%loginurl%'   => __( 'prints out your sites login url', APP_TD ),
		);

		switch ( $option ) {
			case 'idea_approved_body':
				$markup = $available_markup;
				break;
		}

		return $markup;
	}

	protected function email_markup_tip_for( $option ) {

		$markup_tip = __( 'You may use the following variables within the email body and/or subject line.', APP_TD ) . '<br /><br />';

		$markup = self::email_markup_for( $option );

		foreach ( $markup as $name => $desc ) {
			$markup_tip .= "<strong>$name</strong> - $desc <br />";
		}

		$markup_tip .= '<br />' . __( 'Each variable MUST have the percentage signs wrapped around it with no spaces.', APP_TD );

		return $markup_tip;
	}

	protected function init_tabs() {
		$this->tabs->add( 'general', __( 'General', APP_TD ) );
		$this->tabs->add( 'emails', __( 'Emails', APP_TD ) );
		$this->tabs->add( 'reset', __( 'Reset', APP_TD ) );

		$this->tab_sections['general']['appearance'] = array(
			'title' => __( 'Appearance', APP_TD ),
			'fields' => array(
				array(
					'title' => __( 'Theme Color', APP_TD ),
					'type' => 'select',
					'name' => 'color',
					'values' => _ideax_get_color_choices(),
					'tip' => __( 'Choose the overall theme color.', APP_TD ),
				),
				array(
					'title' => __( 'Header Image', APP_TD ),
					'desc' => sprintf( __( 'Set Your Header Image in the <a href="%s">Header</a> settings.', APP_TD ), 'themes.php?page=custom-header' ),
					'type' => 'text',
					'name' => '_blank',
					'extra' => array(
						'style' => 'display: none;'
					),
					'tip' => __( 'This is where you can upload/manage your logo that appears in your site\'s header along with settings to control the text below the logo.', APP_TD ),
				),
			),
		);

		$this->tab_sections['general']['ideas'] = array(
			'title' => __( 'Ideas', APP_TD ),
			'fields' => array(
				array(
					'title' => __( 'Ideas Per Page', APP_TD ),
					'type' => 'text',
					'sanitize' => 'absint',
					'name' => 'ideas_per_page',
					'extra' => array( 'size' => 2 ),
					'tip' => __( 'Set the number of ideas per page.', APP_TD ),
				),
				array(
					'title' => __( 'Max Votes Per User', APP_TD ),
					'type' => 'text',
					'sanitize' => 'absint',
					'name' => 'votes_per_user',
					'extra' => array( 'size' => 2 ),
					'tip' => __( 'Set the number of votes each new user starts with.', APP_TD ),
				),
				array(
					'title' => __( 'Max Votes Per Idea', APP_TD ),
					'desc' => __( '( 0 for Unlimited )', APP_TD ),
					'type' => 'text',
					'sanitize' => 'absint',
					'name' => 'votes_per_idea',
					'extra' => array( 'size' => 2 ),
					'tip' => __( 'Set the number of times a user can vote for one idea.', APP_TD ),
				),
				array(
					'title' => __( 'Related Ideas', APP_TD ),
					'type' => 'text',
					'sanitize' => 'absint',
					'name' => 'related_ideas',
					'extra' => array( 'size' => 2 ),
					'tip' => __( "Choose the number of related ideas that should be displayed on single ideas pages. Leave blank if you don't want to display related ideas.", APP_TD ),
				),
				array(
					'title' => __( 'Require Login to Respond', APP_TD ),
					'name' => 'respond_login_ideas',
					'type' => 'checkbox',
					'desc' => __( 'Yes', APP_TD ),
					'tip' => __( 'Visitors must be logged in before commenting on ideas.', APP_TD ),
				),
			),
		);

		$this->tab_sections['general']['status'] = array(
			'title' => __( 'Status', APP_TD ),
			'fields' => array(
				array(
					'title' => __( 'Moderate Ideas', APP_TD ),
					'name' => 'moderate_ideas',
					'type' => 'checkbox',
					'desc' => __( 'Yes', APP_TD ),
					'tip' => __( 'Choose wheter new submitted ideas should be moderated before being published.', APP_TD ),
				),
				array(
					'title' => __( "Slugs for 'Open' Ideas", APP_TD ),
					'type' => 'text',
					'name' => 'open_status_slug',
					'extra' => array( 'size' => 50 ),
					'tip' => sprintf( __( 'Use this field to add all the status that relate with an open idea, and can be voted and/or commented (i.e: open, under-review). Any other status will be considered as closed and will not allow voting or commenting. Please use comma separated <strong>slugs</strong>. You can find your status slugs on the <a href="%1s">status admin page</a>.', APP_TD ), 'edit-tags.php?taxonomy='.IDEAX_STATUS.'&post_type='.IDEAX_PTYPE ),
				),

			),
		);
/*
		$this->tab_sections['general']['share'] = array(
			'title' => __( 'Share', APP_TD ),
			'fields' => array(
				array(
					'title' => __( 'Twitter ID', APP_TD ),
					'type' => 'text',
					'name' => 'twitter_id',
					'extra' => array( 'size' => 50 ),
					'tip' => __( '', APP_TD ),
				),
				array(
					'title' => __( 'Facebook ID', APP_TD ),
					'type' => 'text',
					'name' => 'facebook_id',
					'extra' => array( 'size' => 50 ),
					'tip' => __( '', APP_TD ),
				),
				array(
					'title' => __( 'Google+ ID', APP_TD ),
					'type' => 'text',
					'name' => 'google_plus_id',
					'extra' => array( 'size' => 50 ),
					'tip' => __( '', APP_TD ),
				),
			),
		);
*/

		$this->tab_sections['general']['security'] = array(
			'title' => __( 'Security Settings', APP_TD ),
			'fields' => array(
				array(
					'title' => __( 'Back Office Access', APP_TD ),
					'desc' => '<br />' . sprintf( __( "View the WordPress <a target='_new' href='%s'>Roles and Capabilities</a> for more information.", APP_TD ), 'http://codex.wordpress.org/Roles_and_Capabilities' ),
					'type' => 'select',
					'name' => 'admin_security',
					'values' => array(
						'manage_options' => __( 'Admins Only', APP_TD ),
						'edit_others_posts' => __( 'Admins, Editors', APP_TD ),
						'publish_posts' => __( 'Admins, Editors, Authors', APP_TD ),
						'edit_posts' => __( 'Admins, Editors, Authors, Contributors', APP_TD ),
						'read' => __( 'All Access', APP_TD ),
						'disable' => __( 'Disable', APP_TD ),
					),
					'tip' => __( 'Allows you to restrict access to the WordPress Back Office (wp-admin) by specific role. Keeping this set to admins only is recommended. Select Disable if you have problems with this feature.', APP_TD ),
				),
			),
		);


		$this->tab_sections['emails']['settings'] = array(
			'title' => __( 'Settings', APP_TD ),
			'fields' => array(
				array(
					'title' => __( 'From Name', APP_TD ),
					'type' => 'text',
					'name' => 'from_name',
					'tip' => __( 'This is what users will see as the &quot;from&quot; when they receive emails. Use plain text only.', APP_TD ),
				),
				array(
					'title' => __( 'From Email', APP_TD ),
					'type' => 'text',
					'name' => 'from_email',
					'tip' => __( 'This is what users will see as the &quot;from&quot; email address (also the reply to) when they receive emails. Use only a valid and existing email address with no html or variables.', APP_TD ),
				),
				array(
					'title' => __( 'Allow HTML in Body', APP_TD ),
					'type' => 'checkbox',
					'name' => 'allow_html',
					'desc' => __( 'Yes', APP_TD ),
					'tip' => __( 'This option allows you to use html markup in the email body below. It is recommended to keep it unchecked to avoid problems with delivery. If you turn it on, make sure to test it and make sure the formatting looks ok and gets delivered properly.', APP_TD ),
				),
			),
		);

		$this->tab_sections['emails']['idea_approved'] = array(
			'title' => __( 'Idea Approved', APP_TD ),
			'fields' => array(
				array(
					'title' => __( 'Subject', APP_TD ),
					'type' => 'text',
					'name' => 'idea_approved_subject',
					'tip' => __( 'This is what users will see on the subject email when an idea is approved. Use text and variables only.', APP_TD ),
				),
				array(
					'title' => __( 'Email Body', APP_TD ),
					'type' => 'textarea',
					'name' => 'idea_approved_body',
					'extra' => array( 'rows' => 10, 'cols' => 100 ),
					'desc' => html( 'p', self::email_markup_tip_for( 'idea_approved_body' ) ),
					'tip' => __( 'Enter the text that should be sent on the email when an idea is approved.
									Always test your new email after making any changes to make sure it is working and formatted correctly.
									If you do not receive an email, chances are something is wrong with your email body.', APP_TD ),
				),
			),
		);

		$this->tab_sections['reset']['reset_monthly'] = array(
			'title' => __( 'Automatic Reset', APP_TD ),
			'fields' => array(
				array(
					'title' => __( 'User Votes Monthly Reset', APP_TD ),
					'name' => 'reset_user_votes_auto',
					'type' => 'checkbox',
					'desc' => __( 'Yes', APP_TD ),
					'tip' => __( 'If you check this option, user votes will be reset each month.', APP_TD ),
				),
			),
		);

		$this->tab_sections['reset']['reset_all'] = array(
			'title' => __( 'Reset All Votes', APP_TD ),
			'fields' => array(
				array(
					'title' => __( 'Reset Votes for All Ideas', APP_TD ),
					'name' => 'reset_all_ideas_votes',
					'type' => 'checkbox',
					'desc' => __( 'Yes', APP_TD ),
					'tip' => __( 'Checking this option will immediately reset all ideas to 0 when you click \'Save Changes\'. This action cannot be undone.', APP_TD ),
				),
				array(
					'title' => __( 'Reset Votes for All Users', APP_TD ),
					'name' => 'reset_all_users_votes',
					'type' => 'checkbox',
					'desc' => __( 'Yes', APP_TD ),
					'tip' => __( 'Checking this option will immediately reset all users casted votes to 0 when you click \'Save Changes\'. This action cannot be undone.', APP_TD ),
				),

			),
		);

	}

	function init_integrated_options() {
		// display additional section on the permalinks page
		$this->permalink_sections();
	}

	function permalink_sections() {

		$option_page = 'permalink';
		$new_section = 'ideax_options';	// store permalink options on global 'ideax_options'

		$this->permalink_sections = array(
			'ideas' => __( 'Ideas Custom Post Type & Taxonomy URLs', APP_TD ),
			'actions' => __( 'Ideas Actions URLs', APP_TD )
		);

		$this->permalink_options['ideas'] = array(
			'ideas_permalink' => __( 'Ideas Base URL', APP_TD ),
			'ideas_cat_permalink' => __( 'Ideas Category Base URL', APP_TD ),
			'ideas_statuses_permalink' => __( 'Ideas Statuses Base URL', APP_TD ),
			'ideas_tag_permalink' => __( 'Ideas Tag Base URL', APP_TD )
		);

		$this->permalink_options['actions'] = array(
			'edit_idea_permalink' => __( 'Edit Idea Base URL', APP_TD )
		);

		register_setting(
			$option_page,
			$new_section,
			array( $this, 'permalink_options_validate' )
		);

		foreach ( $this->permalink_sections as $section => $title ) {

			add_settings_section(
				$section,
				$title,
				'__return_false',
				$option_page
			);

			foreach ( $this->permalink_options[ $section ] as $id => $title ) {

				add_settings_field(
					$new_section . '_' . $id,
					$title,
					array( $this, 'permalink_section_add_option' ), // callback to output the new options
					$option_page, // options page
					$section, // section
					array( 'id' => $id ) // callback args [ database option, option id ]
				);

			}

		}
	}

	function permalink_section_add_option( $option ) {
		global $ideax_options;

		echo scbForms::input( array(
			'type'  => 'text',
			'name'  => 'ideax_options[' . $option['id'] . ']',
			'extra' => array( 'size' => 53 ),
			'value'	=> $ideax_options->$option['id']
		) );

	}

	// validate/sanitize permalinks
	function permalink_options_validate( $input ) {
		global $ideax_options;

		$error_html_id = '';

		foreach ( $this->permalink_sections as $section => $title ) {

			foreach ( $this->permalink_options[ $section ] as $key => $value ) {

				if ( empty( $input[ $key ] ) ) {
					$error_html_id = $key;
					// set option to previous value
					$input[ $key ] = $ideax_options->$key;
				} else {
					if ( ! is_array( $input[ $key ] ) )
						$input[ $key ] = trim( $input[ $key ] );

					$input[ $key ] = stripslashes_deep( $input[ $key ] );
				}

			}
		}

		if ( $error_html_id ) {

			add_settings_error(
				'ideax_options',
				$error_html_id,
				__( 'Ideas custom post type and taxonomy URLs cannot be empty. Empty options will default to previous value.', APP_TD ),
				'error'
			);

		}

		return $input;
	}

	function before_rendering_field( $field ) {
		if ( 'color' == $field['name'] && is_child_theme() ) {
			$field['extra'] = array( 'disabled' => true );
			$field['desc'] = '(' . __( 'chosen by child theme', APP_TD ) . ')';
		} elseif ( 'reset_all_ideas_votes' == $field['name'] ) {
			_e( 'These options allow yout to reset users and/or ideas votes. Responses to ideas are not deleted and will remain visible even after reseting the related votes.', APP_TD );
		}

		return $field;
	}

	function maybe_reset_all_votes() {
		if ( isset( $_POST['reset_all_users_votes'] ) ) {
			$users = get_users();

			foreach ( $users as $user ) {
				ideax_reset_user_votes( $user->ID );
			}

			parent::admin_msg( __( 'All users votes were reset!', APP_TD ) );
		}

		if ( isset( $_POST['reset_all_ideas_votes'] ) ) {
			$ideas = get_posts( array(
				'post_type' => IDEAX_PTYPE,
				'posts_per_page' => -1,
				'post_status' => 'any'
			) );

			foreach ( $ideas as $idea ) {
				ideax_reset_votes( $idea->ID );
			}

			parent::admin_msg( __( 'All ideas votes were reset!', APP_TD ) );
		}
	}

	function clear_reset_votes( $options ) {
		global $ideax_options;

		if ( ! empty( $ideax_options->reset_all_users_votes ) ) {
			$options['reset_all_users_votes'] = '';
		}

		if ( ! empty( $ideax_options->reset_all_ideas_votes ) ) {
			$options['reset_all_ideas_votes'] = '';
		}

		return $options;
	}
}
