<?php

// Update script for version changes


// main update logic check
function ideax_init_updates() {

	list( $args ) = get_theme_support( 'app-versions' );
	$previous_version = get_option( $args['option_key'] );

	// upgrade to version 1.1
	if ( version_compare( $previous_version, '1.1', '<' ) )
		ideax_version_1_1_update();

	// upgrade to version 1.2
	if ( version_compare( $previous_version, '1.2', '<' ) )
		ideax_version_1_2_update();

	// upgrade to version 1.3
	if ( version_compare( $previous_version, '1.3', '<' ) )
		ideax_version_1_3_update();

}
add_action( 'appthemes_first_run', 'ideax_init_updates' );



// upgrade to version 1.1
function ideax_version_1_1_update() {
	global $wpdb;

	// legacy meta keys
	$meta_keys = array(
		'idea_official_response',
		'ideax_idea_total_votes',
		'idea_last_voted_by',
		'idea_official_response',
		'ideax_post_votes',
		'idea_notes'
	);

	// append underscores to post meta fields
	foreach ( $meta_keys as $k ) {
		$sql = $wpdb->prepare( "SELECT meta_id FROM $wpdb->postmeta WHERE meta_key = '%s' LIMIT 1", $k );

		if ( $wpdb->get_results( $sql ) ) {
			$wpdb->update( $wpdb->postmeta, array( 'meta_key' => '_' . $k ), array( 'meta_key' => $k ) );
		}
	}

}


// upgrade to version 1.2
function ideax_version_1_2_update() {

	// move submit idea content into page template
	ob_start();
?>
	<p>Great, you've got an idea and would like to share it with us! Now before you spend valuable time writing it up, we ask that you make sure your idea does not fall under one of the following scenarios:</p>
	<div class="listing box-shadow drop-shadow lifted">
		<div class="listing-info">
			<div class="fancy-list bullet-list">
				<ul>
					<li>Make sure your idea does not already exist.</li>
					<li>Your idea should be a feature request or enhancement. This is not the correct place for theme help. Visit our forums for support assistance.</li>
					<li>Search the ideas exchange and make sure your idea does not already exist. If it does, vote that idea up instead of creating a new one.</li>
				</ul>
			</div>
		</div>
	</div>
	<p>Ok, you're still here so that must mean you passed with flying colors! Continue on below and then submit your idea for our staff to review.</p>
<?php
	$content = ob_get_clean();

	$post['ID'] = IDEAX_Idea_Add::get_id();
	$post['post_content'] = $content;

	wp_update_post( $post );
}


// upgrade to version 1.3
function ideax_version_1_3_update() {

	// set blog and ideas pages
	update_option( 'show_on_front', 'page' );
	update_option( 'page_on_front', IDEAX_Idea_Front::get_id() );
	update_option( 'page_for_posts', IDEAX_Blog_Archive::get_id() );

	// remove old front page
	$args = array(
		'post_type' => 'page',
		'meta_key' => '_wp_page_template',
		'meta_value' => 'archive-idea.php',
		'posts_per_page' => 1,
		'suppress_filters' => true,
	);
	$front_page = new WP_Query( $args );

	if ( ! empty( $front_page->posts ) ) {
		wp_delete_post( $front_page->posts[0]->ID, true );
	}

}
