<?php

// Users capabilities related functions

add_action( 'appthemes_first_run', 'ideax_add_caps' );
add_action( 'admin_init', 'ideax_restrict_admin_access' );
add_filter( 'post_row_actions', 'ideax_disable_quick_edit' );

function ideax_add_caps() {
	ideax_manage_caps( 'add_cap' );
}

function ideax_remove_caps() {
	ideax_manage_caps( 'remove_cap' );
}

function ideax_manage_caps( $operation ) {
	global $wp_roles;

	if ( ! isset( $wp_roles ) )
		$wp_roles = new WP_Roles();

	foreach ( $wp_roles->roles as $role => $details ) {
		foreach ( ideax_get_custom_caps( $role, $operation ) as $cap ) {
			$wp_roles->$operation( $role, $cap );
		}
	}
}

// add/remove additional capabilities to admins and editors
function ideax_get_custom_caps( $role, $operation ) {

	$caps = array(
		'edit_ideas',
	);

	// remove edit/delete posts/ideas capabilities
	if ( in_array( $role, array( 'editor', 'administrator' ) ) ) {
		$caps = array_merge( $caps, array(
			'edit_others_ideas',
			'publish_ideas',
			'delete_ideas',
			'delete_others_ideas'
		) );
	}

	return $caps;
}

/**
 * Admin area access control with redirect
 */
function ideax_restrict_admin_access() {
	global $ideax_options;

	$access_level = $ideax_options->admin_security;

	if ( empty( $access_level ) ) {
		$access_level = 'manage_options';
	}

	if ( $access_level == 'disable' || current_user_can( $access_level ) || defined( 'DOING_AJAX' ) ) {
		return;
	} else {
		wp_redirect( home_url( '/' ) );
		exit;
	}
}

/**
 * Disables 'Quick Edit' functionality for users with role lower than Editor
 */
function ideax_disable_quick_edit( $actions ) {
	if ( ! current_user_can( 'edit_others_posts' ) ) {
		unset( $actions['inline hide-if-no-js'] );
	}

	return $actions;
}
