<?php

// Core functions

add_action( 'wp_login', 'ideax_periodic_reset', 10, 2 );

// periodically reset user votes if set by user
function ideax_periodic_reset( $user_login, $user ) {
	global $ideax_options;

	if ( ! $ideax_options->reset_user_votes_auto )
		return;

	$user_id = $user->ID;
	$old_date = $cur_date = '';

	// reset user votes if need be
	if ( $last_reset_date = get_user_meta( $user_id, 'ideax_user_votes_last_reset_date', true ) ) {
		// is reset month/year same as current month/year? If not, reset vote count back and update to current date
		$old_date = date( 'Y-m', strtotime( $last_reset_date ) );
		$cur_date = date( 'Y-m', strtotime( current_time('mysql') ) );
	}

	// update date and reset votes
	if ( $old_date < $cur_date || ! $last_reset_date ) {
		ideax_reset_user_votes( $user_id );
	}
}

function ideax_register_post_types() {
	global $ideax_options;

	$labels = array(
		'name' => __( 'Ideas', APP_TD ),
		'singular_name' => __( 'Idea', APP_TD ),
		'add_new' => __( 'Add New', APP_TD ),
		'add_new_item' => __( 'Add New Idea', APP_TD ),
		'edit_item' => __( 'Edit Idea', APP_TD ),
		'new_item' => __( 'New Idea', APP_TD ),
		'view_item' => __( 'View Idea', APP_TD ),
		'search_items' => __( 'Search Ideas', APP_TD ),
		'not_found' => __( 'No ideas found', APP_TD ),
		'not_found_in_trash' => __( 'No ideas found in Trash', APP_TD ),
		'parent_item_colon' => __( 'Parent Idea:', APP_TD ),
		'menu_name' => __( 'Ideas', APP_TD ),
	);

	$custom_caps = array(
		'publish_posts' => 'publish_ideas',
		'edit_posts' => 'edit_ideas',
		'edit_others_posts' => 'edit_others_ideas',
		'delete_posts' => 'delete_ideas',
		'delete_others_posts' => 'delete_others_ideas',
		'read_private_posts' => 'read_private_ideas',
		'edit_post' => 'edit_idea',
		'delete_post' => 'delete_idea',
		'read_post' => 'read_idea',
	);

	$args = array(
		'labels' => $labels,
		'hierarchical' => false,

		'supports' => array( 'title', 'editor', 'excerpt', 'author', 'thumbnail', 'comments', 'revisions' ),

		'public' => true,
		'show_ui' => true,
		'show_in_menu' => true,
		'menu_position' => 6,
		'menu_icon' => appthemes_locate_template_uri( 'images/admin-menu.png' ),

		'show_in_nav_menus' => false,
		'publicly_queryable' => true,
		'exclude_from_search' => false,
		'has_archive' => true,
		'query_var' => true,
		'can_export' => true,
		'rewrite' => array( 'slug' => $ideax_options->ideas_permalink, 'with_front' => false ),
		'capabilities' => $custom_caps,
		'map_meta_cap' => true,
		'update_count_callback' => '_update_post_term_count'
	);

	if ( current_user_can( 'edit_others_posts' ) )
		$args['supports'][] = 'custom-fields';

	register_post_type( IDEAX_PTYPE, $args );
}

function ideax_register_taxonomies() {
	global $ideax_options;

	$labels = array(
		'name' => __( 'Ideas Categories', APP_TD ),
		'singular_name' => __( 'Idea Category', APP_TD ),
		'search_items' => __( 'Search Ideas Categories', APP_TD ),
		'all_items' => __( 'All Categories', APP_TD ),
		'parent_item' => __( 'Parent Idea Category', APP_TD ),
		'parent_item_colon' => __( 'Parent Idea Category:', APP_TD ),
		'edit_item' => __( 'Edit idea Category', APP_TD ),
		'update_item' => __( 'Update Idea Category', APP_TD ),
		'add_new_item' => __( 'Add New Idea Category', APP_TD ),
		'new_item_name' => __( 'New Idea Category Name', APP_TD ),
		'add_or_remove_items' => __( 'Add or remove ideas categories', APP_TD ),
		'menu_name' => __( 'Categories', APP_TD ),
	);

	$args = array(
		'labels' => $labels,
		'public' => true,

		'show_ui' => true,
		'show_admin_column' => true,

		'show_in_nav_menus' => true,
		'show_tagcloud' => false,
		'hierarchical' => true,

		'query_var' => true,
		'rewrite' => array( 'slug' => $ideax_options->ideas_permalink . '/' . $ideax_options->ideas_cat_permalink, 'with_front' => false ),
	);

	register_taxonomy( IDEAX_CATEGORY, IDEAX_PTYPE, $args );

	$labels = array(
		'name' => __( 'Ideas Statuses', APP_TD ),
		'singular_name' => __( 'Idea Status', APP_TD ),
		'search_items' => __( 'Search Ideas Statuses', APP_TD ),
		'all_items' => __( 'All Statuses', APP_TD ),
		'parent_item' => __( 'Parent Idea Status', APP_TD ),
		'parent_item_colon' => __( 'Parent Idea Status:', APP_TD ),
		'edit_item' => __( 'Edit Idea Status', APP_TD ),
		'update_item' => __( 'Update Idea Status', APP_TD ),
		'add_new_item' => __( 'Add New Idea Status', APP_TD ),
		'new_item_name' => __( 'New Idea Status Name', APP_TD ),
		'separate_items_with_commas' => __( 'Separate ideas statuses with commas', APP_TD ),
		'add_or_remove_items' => __( 'Add or remove ideas statuses', APP_TD ),
		'menu_name' => __( 'Statuses', APP_TD ),
	);

	$args = array(
		'labels' => $labels,
		'public' => true,

		'show_ui' => true,
		'show_admin_column' => true,

		'show_in_nav_menus' => true,
		'show_tagcloud' => false,
		'hierarchical' => true,

		'query_var' => true,
		'rewrite' => array( 'slug' => $ideax_options->ideas_permalink . '/' . $ideax_options->ideas_statuses_permalink, 'with_front' => false ),
	);

	register_taxonomy( IDEAX_STATUS, IDEAX_PTYPE, $args );

	$labels = array(
		'name' => __( 'Ideas Tags', APP_TD ),
		'singular_name' => __( 'Idea Tag', APP_TD ),
		'search_items' => __( 'Search Ideas Tags', APP_TD ),
		'popular_items' => __( 'Popular Ideas Tags', APP_TD ),
		'all_items' => __( 'All Tags', APP_TD ),
		'parent_item' => __( 'Parent Idea Tag', APP_TD ),
		'parent_item_colon' => __( 'Parent Idea Tag:', APP_TD ),
		'edit_item' => __( 'Edit Idea Tag', APP_TD ),
		'update_item' => __( 'Update Idea Tag', APP_TD ),
		'add_new_item' => __( 'Add New Idea Tag', APP_TD ),
		'new_item_name' => __( 'New Idea Tag Name', APP_TD ),
		'separate_items_with_commas' => __( 'Separate ideas tags with commas', APP_TD ),
		'add_or_remove_items' => __( 'Add or remove ideas tags', APP_TD ),
		'menu_name' => __( 'Tags', APP_TD ),
	);

	$args = array(
		'labels' => $labels,
		'public' => true,

		'show_in_nav_menus' => true,
		'show_ui' => true,
		'show_admin_column' => true,

		'show_tagcloud' => true,
		'hierarchical' => false,

		'query_var' => true,
		'rewrite' => array( 'slug' => $ideax_options->ideas_permalink . '/' . $ideax_options->ideas_tag_permalink, 'with_front' => false ),
	);

	register_taxonomy( IDEAX_TAG, IDEAX_PTYPE, $args );

}

function ideax_add_style() {
	global $ideax_options, $wp_styles;

	if ( is_child_theme() )
		return;

	wp_enqueue_style(
		'ideax-normalize',
		get_template_directory_uri() . "/styles/normalize.css",
		array(),
		IDEAX_VERSION
	);

	wp_enqueue_style(
		'at-color',
		get_template_directory_uri() . "/styles/$ideax_options->color.css",
		array(),
		IDEAX_VERSION
	);
}

// Scripts loaded on all pages
function ideax_add_scripts() {
	global $wp_scripts;

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );

	wp_enqueue_script( 'validate' );
	wp_enqueue_script( 'validate-lang' );

	// used to convert header menu into select list on mobile devices
	wp_enqueue_script(
		'tinynav',
		get_template_directory_uri() . '/scripts/jquery.tinynav.min.js',
		array( 'jquery' ),
		'1.2',
		true
	);

	wp_enqueue_script(
		'ideax-scripts',
		get_template_directory_uri() . '/scripts/scripts.js',
		array( 'jquery' ),
		IDEAX_VERSION,
		true
	);

	wp_localize_script( 'ideax-scripts', 'Ideas', array(
		'home_url' => home_url( '/' ),
		'ajaxurl' => admin_url( 'admin-ajax.php', 'relative' ),
		'current_url' => scbUtil::get_current_url(),
		'text_mobile_navigation' => __( 'Navigation', APP_TD ),
	) );
}

function ideax_setup_theme() {
	// Menus
	register_nav_menu( 'header', __( 'Header Menu', APP_TD ) );
	register_nav_menu( 'footer', __( 'Footer Menu', APP_TD ) );

	// Sidebars
	ideax_register_sidebar( 'main', __( 'Main Sidebar', APP_TD ), __( 'The sidebar appearing on all pages except search, pages, blog, and the single idea page', APP_TD ) );
	ideax_register_sidebar( 'header', __( 'Header Sidebar', APP_TD ), __( 'An optional widget area for your site header', APP_TD ) );

	ideax_register_sidebar( 'single-idea', __( 'Single Idea Sidebar', APP_TD ), __( 'The sidebar for the single idea page', APP_TD ) );
	ideax_register_sidebar( 'search-idea', __( 'Search Idea Sidebar', APP_TD ), __( 'The sidebar for the ideas search page', APP_TD ) );
	ideax_register_sidebar( 'add-idea', __( 'Submit Idea Sidebar', APP_TD ), __( 'The sidebar for the submit idea page', APP_TD ) );

	ideax_register_sidebar( 'page', __( 'Pages Sidebar', APP_TD ), __( 'The sidebar for pages', APP_TD ) );
	ideax_register_sidebar( 'post', __( 'Blog Sidebar', APP_TD ), __( 'The sidebar for the blog page', APP_TD ) );
	ideax_register_sidebar( 'single', __( 'Blog Single Sidebar', APP_TD ), __( 'The sidebar for individual blog posts', APP_TD ) );

	ideax_register_sidebar( 'footer-col-1', __( 'Footer Column 1', APP_TD ), __( 'An optional widget area for your site footer', APP_TD ), 'fl' );
	ideax_register_sidebar( 'footer-col-2', __( 'Footer Column 2', APP_TD ), __( 'An optional widget area for your site footer', APP_TD ), 'fl' );
	ideax_register_sidebar( 'footer-col-3', __( 'Footer Column 3', APP_TD ), __( 'An optional widget area for your site footer', APP_TD ), 'fl' );

}

function ideax_redirect_to_front_page() {
	if ( ! isset( $_REQUEST['redirect_to'] ) ) {
		wp_redirect( home_url() );
		exit();
	}
}

function ideax_login_logo_url() {
	return get_bloginfo( 'url' );
}

function ideax_login_logo_url_title() {
	return get_bloginfo( 'description' );
}

function ideax_body_class( $classes ) {
	if ( ! is_user_logged_in() )
		$classes[] = 'not-logged-in';

	return $classes;
}

function _ideax_get_color_choices() {
	return apply_filters( 'ideax_theme_colors', array(
		'blue' 	=> __( 'Blue', APP_TD ),
		'green' => __( 'Green', APP_TD ),
		'grey' 	=> __( 'Grey', APP_TD ),
		'orange'=> __( 'Orange', APP_TD ),
		'red' 	=> __( 'Red', APP_TD ),
	) );
}

function ideax_stats_count() {

	$args = array(
		'post_type' => IDEAX_PTYPE,
		'count'     => true
	);

	$stats = array(
		'ideas'     => wp_count_posts( $args['post_type'] )->publish,
		'responses' => get_comments( $args )
	);

	return $stats;
}


function ideax_vote_arrows() {
	global $post;

	ob_start();
?>
	<div id="vote-wrapper" class="clear">
		<?php if ( ! ideax_is_idea_open( get_the_ID() ) ) { ?>
			<div id="voteclosed"><?php _e( 'Voting has ended.', APP_TD ); ?></div>
		<?php } elseif ( is_user_logged_in() ) { ?>
			<div id="voteerror"></div>
			<div id="loading"></div>
			<div class="listing-counter-votes" id="vote-up-down">
				<a class="up" href="#" title="<?php esc_attr_e( 'Vote this idea up', APP_TD ); ?>" alt="<?php esc_attr_e( 'Vote this idea up', APP_TD ); ?>"></a>
				<a class="down" href="#" title="<?php esc_attr_e( 'Vote this idea down', APP_TD ); ?>" alt="<?php esc_attr_e( 'Vote this idea down', APP_TD ); ?>"></a>
			</div>
		<?php } else { ?>
			<div id="votevisitor"><?php printf( __( "<a href='%s'>Log in</a> to vote.", APP_TD ), wp_login_url( get_permalink() ) ); ?></div>
		<?php } ?>
	</div>
<?php
	return ob_get_clean();
} 


// allowed tags in comments and new idea submissions
function ideax_allowed_tags() {
	global $allowedtags;

	$allowedtags['ul'] = array();
	$allowedtags['ol'] = array();
	$allowedtags['li'] = array();
	$allowedtags['strong'] = array();
	$allowedtags['pre'] = array(
		'lang' => true,
		'line' => true
	);
	$allowedtags['a'] = array(
		'target' => true,
		'href' => true,
		'title' => true,
	);
}
add_action( 'init', 'ideax_allowed_tags' );


// add more buttons to html front-end editor
function ideax_additional_quicktags() {
?>
	<script type="text/javascript">
		if ( typeof QTags != 'undefined' ) {
			QTags.addButton( 'eg_pre', 'pre', '<pre>', '</pre>', 'q', 'pre', 111 );
		}
	</script>
<?php
}
add_action( 'wp_footer', 'ideax_additional_quicktags', 100 );


// exclude pages from blog search results
function ideax_exclude_from_search( $query ) {

	if ( is_admin() || isset( $_GET['s_idea'] ) ) {
		return $query;
	}

	if ( $query->is_search && $query->is_main_query() ) {
		$query->set( 'post_type', 'post' );
	}

	return $query;
}
add_filter( 'pre_get_posts', 'ideax_exclude_from_search' );


/**
 * Build Search Index for past items
 */
function _ideax_setup_build_search_index() {
	if ( ! current_theme_supports( 'app-search-index' ) ) {
		return;
	}

	appthemes_add_instance( 'APP_Build_Search_Index' );
}
add_action( 'init', '_ideax_setup_build_search_index', 100 );


/**
 * Register items to index, post types, taxonomies, and custom fields
 */
function ideax_register_search_index_items() {
	if ( ! current_theme_supports( 'app-search-index' ) ) {
		return;
	}

	// Idea listings
	$listing_index_args = array(
		'meta_keys' => array( '_idea_official_response' ),
		'taxonomies' => array( IDEAX_CATEGORY, IDEAX_TAG, IDEAX_STATUS ),
	);
	APP_Search_Index::register( IDEAX_PTYPE, $listing_index_args );

}
add_action( 'init', 'ideax_register_search_index_items', 10 );


/**
 * Whether the Search Index is ready to use
 */
function ideax_search_index_enabled() {
	if ( ! current_theme_supports( 'app-search-index' ) ) {
		return false;
	}

	return apply_filters( 'ideax_search_index_enabled', appthemes_get_search_index_status() );
}

