<?php

// Template tags used on ideas Loops

/**
 * Ideas
 *
 */

// returns the url for submitting ideas
function ideax_get_add_idea_url() {
	return get_permalink( IDEAX_Idea_Add::get_id( 'add-idea.php' ) );
}

// returns the url for editing ideas
function ideax_get_idea_edit_url( $idea_id ) {
	global $wp_rewrite, $ideax_options;

	if ( $wp_rewrite->using_permalinks() ) {
		$base = $ideax_options->ideas_permalink;
		$permalink = $base . '/' . $ideax_options->edit_idea_permalink;
		return home_url( user_trailingslashit( "$permalink/$idea_id" ) );
	}

	return home_url( "?idea_edit=$idea_id" );
}

// returns the first term for an idea
function get_the_idea_terms( $idea_id, $tax ) {
	$terms = get_the_terms( $idea_id, $tax );
	if ( ! $terms )
		return false;

	return reset( $terms );
}

// get the current or specified idea votes
function get_the_votes( $idea_id = 0 ) {
	$idea_id = ! empty( $idea_id ) ? $idea_id : get_the_ID();
	return intval( get_post_meta( $idea_id, '_ideax_idea_total_votes', true ) );
}

// outputs the current or specified idea votes
function the_votes( $idea_id = 0 ) {
	echo number_format_i18n( get_the_votes( $idea_id ) );
}

// get the current or specified idea comments/responses
function get_the_responses( $idea_id = 0 ) {
	$idea_id = ! empty( $idea_id ) ? $idea_id : get_the_ID();
	return intval( get_comments_number( $idea_id ) );
}

// outputs the current or specified idea comments/responses
function the_responses( $idea_id = 0 ) {
	$idea_id = ! empty( $idea_id ) ? $idea_id : get_the_ID();
	echo number_format_i18n( get_the_responses( $idea_id ) );
}

// outputs the current idea tags
function the_idea_tags( $before = null, $sep = ', ', $after = '' ) {
	if ( null === $before ) {
		$before = __( 'Tags: ', APP_TD );
	}

	echo get_the_term_list( get_the_ID(), IDEAX_TAG, $before, $sep, $after );
}

// outputs the current or specified idea category
function the_idea_category( $idea_id = 0 ) {
	$idea_id = ! empty( $idea_id ) ? $idea_id : get_the_ID();

	echo get_the_term_list( $idea_id, IDEAX_CATEGORY, '', ', ', '' );
}

// outputs the current or specified idea status
function the_idea_status( $idea_id = 0 ) {
	$idea_id = ! empty( $idea_id ) ? $idea_id : get_the_ID();

	echo get_the_term_list( $idea_id, IDEAX_STATUS, '', ', ', '' );
}

// outputs the current or specified idea status slug
function the_idea_status_slug( $idea_id = 0 ) {
	$idea_id = ! empty( $idea_id ) ? $idea_id : get_the_ID();

	$slugs = array();

	$terms = get_the_terms( $idea_id, IDEAX_STATUS );
	if ( ! $terms )
		return;

	foreach ( $terms as $term ) {
		$slugs[] = $term->slug;
	}

	echo implode( ' ', $slugs );
}

// outputs the current or specified idea comments count
function the_idea_comments_count( $idea_id = 0 ) {
	$idea_id = ! empty( $idea_id ) ? $idea_id : get_the_ID();

	$count_comments = wp_count_comments( $idea_id )->approved;
	echo $count_comments;
}

// returns the current or specified idea time
function idea_get_idea_time( $idea_id = 0 ) {
	$idea_id = ! empty( $idea_id ) ? $idea_id : get_the_ID();
	return human_time_diff( get_the_time( 'U', $idea_id ), current_time( 'timestamp' ) );
}

// outputs the current or specified idea time
function the_idea_time( $idea_id = 0 ) {
	$idea_time = idea_get_idea_time( $idea_id );
	printf( __( 'Added %s ago', APP_TD ), $idea_time );
}


// returns the current or specified idea modified time
function idea_get_idea_modified_time( $idea_id = 0 ) {
	$idea_id = ! empty( $idea_id ) ? $idea_id : get_the_ID();
	return human_time_diff( get_the_modified_time( 'U', $idea_id ), current_time( 'timestamp' ) );
}

// returns the current or specified idea edit link
function the_idea_edit_link( $idea_id = 0, $before = '', $after = '' ) {
	$idea_id = $idea_id ? $idea_id : get_the_ID();

	if ( ! current_user_can( 'edit_idea', $idea_id ) )
		return;

	$text = __( 'Edit Idea', APP_TD );

	 $link = html( 'a', array(
		'class' => 'idea-edit-link',
		'href' => ideax_get_idea_edit_url( $idea_id ),
	), $text );

	echo $before . apply_filters( 'the_idea_edit_link', $link ) . $after;
}

// edit categories
function the_idea_edit_categories_field( $idea = false ) {
	require_once ABSPATH . '/wp-admin/includes/template.php';

	$multiselect = apply_filters( 'ideax_can_multiselect_categories', current_user_can( 'edit_others_posts' ) );

	if ( $multiselect ) {

		$idea_id = ( $idea ) ? $idea->ID : 0;
		ob_start();
		wp_terms_checklist( $idea_id, array(
			'taxonomy' => IDEAX_CATEGORY,
			'selected_cats' => false,
			'checked_ontop' => false,
			'walker' => null,
			'descendants_and_self' => 0,
		) );
		$output = ob_get_clean();
		echo html( 'label', array( 'class' => 'error', 'for' => 'tax_input[idea_category][]' ), '' );
		echo html( 'div', array( 'id' => 'multi-categories-checkboxes' ), html( 'ul', $output ) );

	} else {

		$category = ( $idea ) ? $idea->category : 0;
		wp_dropdown_categories( array(
			'id' => 'idea-category',
			'taxonomy' => IDEAX_CATEGORY,
			'hide_empty' => false,
			'hierarchical' => true,
			'name' => 'tax_input[idea_category][]',
			'selected' => $category,
			'show_option_none' => __( 'Select Category', APP_TD ),
			'class' => 'gradient required',
			'orderby' => 'name',
		) );

	}

}

/**
 * Ideas/Users
 *
 */

// returns the username of the current or specified autor
function get_the_idea_author( $user_id = 0 ) {
	$username = get_the_author_meta( 'display_name', $user_id );
	return $username;
}

// outputs the username of the current or specified autor
function the_idea_author( $user_id = 0, $username = '' ) {
	if ( ! $user_id ) $user_id = get_the_author_meta( 'ID' );
	if ( ! $username ) $username = get_the_idea_author( $user_id );
	echo html_link( get_author_posts_url( $user_id ), $username );
}

// outputs the current or specified user ideas count
function the_author_ideas_count( $user_id = 0 ) {
	if ( ! $user_id )
		$user_id = get_the_author_meta( 'ID' );

	$args = array(
		'numberposts' => -1,
		'post_type' => IDEAX_PTYPE,
		'author' => $user_id,
		'post_status' => 'publish',
	);
	$ideas = get_posts( $args );
	echo number_format_i18n( count( $ideas ) );
}

// outputs the current or specified user gravatar
function the_author_gravatar( $user_id = '' ) {
	$user_id = get_the_author_meta( 'ID' );
	$avatar = get_avatar( $user_id, 32 );

	if ( $avatar )
		echo html_link( get_author_posts_url( $user_id ), $avatar );
}

// outputs the current or specified user comments count
function the_user_comments_count( $user_id = 0 ) {
	global $post;

	if ( ! $user_id )
		$user_id = get_the_author_meta( 'ID' );

	$comments = get_comments( array(
		'post_type' => $post->post_type,
		'post_id' => get_the_ID(),
		'status' => 'approve',
		'user_id' => $user_id,
		'count' => 1
	) );
	echo $comments;
}

// outputs the specified user join date
function the_user_join_date( $user_id ) {
	$user = get_userdata( $user_id );

	if ( ! $user ) {
		_e( 'Guest', APP_TD );
	} else {
		echo '<strong>' . mysql2date( 'y/m', $user->user_registered ) . '</strong>' . __( 'Joined', APP_TD );
	}
}


/**
 * Posts
 *
 */


// output the byline
function ideax_entry_meta() {
	// Translators: used between list items, there is a space after the comma.
	$categories_list = get_the_category_list( ', ' );

	// Translators: used between list items, there is a space after the comma.
	$tag_list = get_the_tag_list( '', ', ' );

	$date = sprintf( '<a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date updated" datetime="%3$s" itemprop="dateCreated">%4$s</time></a>',
		esc_url( get_permalink() ),
		esc_attr( get_the_time() ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() )
	);

	$author = sprintf( '<span class="author vcard" itemprop="name"><a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a></span>',
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		esc_attr( sprintf( __( 'View all posts by %s', APP_TD ), get_the_author() ) ),
		get_the_author()
	);

	// Translators: 1 is category, 2 is tag, 3 is the date and 4 is the author's name.
	if ( $tag_list ) {
		$utility_text = __( 'Posted in %1$s and tagged %2$s on %3$s<span class="by-author"> by %4$s</span>.', APP_TD );
	} elseif ( $categories_list ) {
		$utility_text = __( 'Posted in %1$s on %3$s<span class="by-author"> by %4$s</span>.', APP_TD );
	} else {
		$utility_text = __( 'Posted on %3$s<span class="by-author"> by %4$s</span>.', APP_TD );
	}

	printf(
		$utility_text,
		$categories_list,
		$tag_list,
		$date,
		$author
	);
}

