<?php

function ideax_register_widgets() {
	register_widget( 'IDEAX_Widget_Add_Idea_Button' );
	register_widget( 'IDEAX_Widget_Stat_Counter' );
	register_widget( 'IDEAX_Widget_Categories' );
	register_widget( 'IDEAX_Widget_Recent_Ideas' );
	register_widget( 'IDEAX_Widget_Popular_Ideas' );
	register_widget( 'IDEAX_Widget_Recent_Comments' );
	register_widget( 'IDEAX_Widget_Quick_Info' );
	register_widget( 'IDEAX_Widget_Voters' );

	// remove some default WP widgets
	unregister_widget( 'WP_Widget_Meta' );
	//unregister_widget( 'WP_Widget_Search' );
	unregister_widget( 'WP_Widget_Calendar' );

}
add_action( 'widgets_init', 'ideax_register_widgets' );



// widget_stat-counter cursive
class IDEAX_Widget_Add_Idea_Button extends WP_Widget {

	function __construct() {
		$widget_ops = array(
			'description' => __( 'A button for submitting a new Idea', APP_TD ),
			'classname' => 'widget_submit-listing clear'
		);

		parent::__construct( 'ideax-submit-idea-button', __( 'Ideas Theme - Submit Idea Button', APP_TD ), $widget_ops );
	}

	function widget( $args, $instance ) {
		extract( $args );

		$label = empty( $instance['label'] ) ? __( 'Submit Your Idea', APP_TD ) : $instance['label'];

		$url = ideax_get_add_idea_url();

		if ( is_tax( IDEAX_CATEGORY ) )
			$url = add_query_arg( IDEAX_CATEGORY, get_queried_object_id(), $url );

		echo $before_widget;

		echo html( 'a', array(
				'class' => 'cta-gradient submit-listing-button cta-button gradient',
				'href' => $url ),
			$label );

		echo $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['label'] = strip_tags( $new_instance['label'] );

		return $instance;
	}

	function form( $instance ) {
		//Defaults
		$instance = wp_parse_args( (array) $instance, array( 'label' => '' ) );
		$label = isset( $instance['label'] ) ? $instance['label'] : '';
?>
		<p><label for="<?php echo $this->get_field_id( 'label' ); ?>"><?php _e( 'Label:', APP_TD ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'label' ); ?>" name="<?php echo $this->get_field_name( 'label' ); ?>" type="text" value="<?php echo $label; ?>" /></p>
<?php
	}
}

class IDEAX_Widget_Stat_Counter extends WP_Widget {

	function __construct() {
		$widget_ops = array(
			'description' => __( 'Ideas/Responses Stats', APP_TD ),
			'classname' => 'widget_stat-counter cursive'
		);

		parent::__construct( 'ideax-stat-counter', __( 'Ideas Theme - Ideas/Responses Stats', APP_TD ), $widget_ops );
	}

	function widget( $args, $instance ) {
		extract( $args );

		echo $before_widget;

		$html_stats = '';

		$stats_label = array(
			'ideas' => _n_noop( '%s Idea', '%s Ideas', APP_TD ),
			'responses' => _n_noop( '%s Response', '%s Responses', APP_TD ),
		);

		$stats = ideax_stats_count();
		foreach ( $stats as $type => $count ) {
			$html_count = html( 'span', array( 'class' => 'stat-counter-highlight' ), $count );
			$html_stats .= html( 'li', sprintf( translate_nooped_plural( $stats_label[ $type ], $count, APP_TD ), $html_count ) );
		}
		echo html( 'ul',  $html_stats );

		echo $after_widget;
	}

}

class IDEAX_Widget_Categories extends WP_Widget {

	function __construct() {
		$widget_ops = array(
			'description' => __( 'Ideas Categories', APP_TD ),
			'classname' => 'widget_ideas-cats'
		);

		parent::__construct( 'ideax-category-list', __( 'Ideas Theme - Categories', APP_TD ), $widget_ops );
	}

	function widget( $args, $instance ) {
		extract( $args );

		$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? __( 'Categories', APP_TD ) : $instance['title'], $instance, $this->id_base );
		$c = ! empty( $instance['count'] ) ? '1' : '0';
		$h = 1;

		echo $before_widget;
		if ( $title )
			echo $before_title . $title . $after_title;

		$taxonomy = IDEAX_CATEGORY;
		$hide_empty = false;
		$depth = 1;

		$curr_cat = null;

		if ( is_home() ) {
			$child_of = 0;

		} elseif ( is_page() ) {

			$child_of = 0;

		} elseif ( is_tax( IDEAX_CATEGORY ) ) {

			$term_slug = get_query_var( IDEAX_CATEGORY );

			$term_info = get_term_by( 'slug', $term_slug, IDEAX_CATEGORY );
			$child_of = $term_info->term_id;

			$args = array(
				'taxonomy' => IDEAX_CATEGORY,
				'child_of' => $child_of,
				'hide_empty'=> 0,
			);

			$term_children = get_categories( $args );
			if ( empty( $term_children ) ) {
				$category_id = $child_of;
				$category_tax = IDEAX_CATEGORY;
				$category_alt = get_term( $category_id, $category_tax );
				$cat_parent = $category_alt->parent;
				$child_of = $cat_parent;
			}


		} elseif ( is_singular( IDEAX_PTYPE ) ) {
			$the_terms = get_the_terms( get_the_ID(), IDEAX_CATEGORY );

			foreach ( $the_terms as $term ) {
				$first_term = $term;
				break;
			}

			$cat = $first_term->term_id;
			$child_of = $cat;
			$curr_cat = $cat;

			$category_id = $cat;
			$category_tax = IDEAX_CATEGORY;
			$category_alt = get_term( $category_id, $category_tax );
			$cat_parent = $category_alt->parent;
			$child_of = $cat_parent;
		} else {
			$child_of = 0;
		}

		$cat_args = array( 'orderby' => 'name', 'show_count' => $c, 'hierarchical' => $h, 'taxonomy' => $taxonomy, 'child_of' => $child_of, 'hide_empty' => $hide_empty, 'depth' => $depth );
?>
		<div class="widget-content">
			<ul>
<?php
				$cat_args['title_li'] = '';
				wp_list_categories( apply_filters( 'widget_categories_args', $cat_args ) );
?>
			</ul>
		</div>
<?php
		echo $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['count'] = !empty( $new_instance['count'] ) ? 1 : 0;

		return $instance;
	}

	function form( $instance ) {
		//Defaults
		$instance = wp_parse_args( (array) $instance, array( 'title' => '' ) );
		$title = esc_attr( $instance['title'] );
		$count = isset( $instance['count'] ) ? (bool) $instance['count'] : false;
?>
		<p><label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', APP_TD ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" /></p>

		<input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id( 'count' ); ?>" name="<?php echo $this->get_field_name( 'count' ); ?>"<?php checked( $count ); ?> />
		<label for="<?php echo $this->get_field_id( 'count' ); ?>"><?php _e( 'Show post counts', APP_TD ); ?></label><br />
<?php
	}

}

class IDEAX_Widget_Recent_Ideas extends WP_Widget {

	function __construct() {
		$widget_ops = array(
			'description' => __( 'The most recent ideas', APP_TD ),
			'classname' => 'clear'
		);
		parent::__construct( 'ideax-recent-ideas', __( 'Ideas Theme - Recent Ideas', APP_TD ), $widget_ops );

		$this->alt_option_name = 'ideax_widget_recent_ideas';

		add_action( 'save_post', array( &$this, 'flush_widget_cache' ) );
		add_action( 'deleted_post', array( &$this, 'flush_widget_cache' ) );
		add_action( 'switch_theme', array( &$this, 'flush_widget_cache' ) );
	}

	function widget( $args, $instance ) {
		$cache = wp_cache_get( 'widget_recent_ideas', 'widget' );

		if ( ! is_array( $cache ) )
			$cache = array();

		if ( ! isset( $args['widget_id'] ) )
			$args['widget_id'] = $this->id;

		if ( isset( $cache[ $args['widget_id'] ] ) ) {
			echo $cache[ $args['widget_id'] ];
			return;
		}

		ob_start();
		extract( $args );

		$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? __( 'Recent Ideas', APP_TD ) : $instance['title'], $instance, $this->id_base );
		if ( empty( $instance['number'] ) || ! $number = absint( $instance['number'] ) )
			$number = 10;

		$r = new WP_Query( array( 'post_type' => IDEAX_PTYPE, 'posts_per_page' => $number, 'no_found_rows' => true, 'post_status' => 'publish', 'ignore_sticky_posts' => true ) );
		if ( $r->have_posts() ) :
		?>
			<?php echo $before_widget; ?>
			<?php if ( $title ) echo $before_title . $title . $after_title; ?>
			<div class="widget-content">
			<?php while ( $r->have_posts() ) : $r->the_post(); ?>
				<div class="widget-idea">
					<?php the_author_gravatar(); ?>
					<div class="widget-idea-body clear">
						<h4><a href="<?php the_permalink() ?>" title="<?php echo esc_attr( get_the_title() ? get_the_title() : get_the_ID() ); ?>"><?php if ( get_the_title() ) the_title(); else the_ID(); ?></a></h4>
						<div class="widget-idea-author"><?php the_idea_author(); ?></div>
						<div class="widget-listing-category">
							<span class="category"><?php the_idea_category(); ?></span> / <span class="status open"><?php the_idea_status(); ?></span>
						</div><!-- /.listing-category -->
					</div><!-- /.widget-idea-body -->
				</div><!-- /.widget-idea -->
			<?php endwhile; ?>
			</div>
			<?php echo $after_widget; ?>
		<?php
			// Reset the global $the_post as this query will have stomped on it
			wp_reset_postdata();

		endif;

		$cache[ $args['widget_id'] ] = ob_get_flush();
		wp_cache_set( 'ideax_widget_recent_ideas', $cache, 'widget' );
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['number'] = (int) $new_instance['number'];
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset( $alloptions['ideax_widget_recent_ideas'] ) )
			delete_option( 'ideax_widget_recent_ideas' );

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete( 'ideax_widget_recent_ideas', 'widget' );
	}

	function form( $instance ) {
		$title = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$number = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
?>
		<p><label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', APP_TD ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" /></p>

		<p><label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of ideas to show:', APP_TD ); ?></label>
		<input id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="text" value="<?php echo $number; ?>" size="3" /></p>
<?php
	}
}

class IDEAX_Widget_Popular_Ideas extends WP_Widget {

	function __construct() {
		$widget_ops = array(
			'description' => __( 'The most popular ideas', APP_TD ),
			'classname' => 'widget_popular-ideas clear'
		);
		parent::__construct( 'ideax-popular-ideas', __( 'Ideas Theme - Popular Ideas', APP_TD ), $widget_ops );

		$this->alt_option_name = 'ideax_widget_popular_ideas';

		add_action( 'save_post', array( &$this, 'flush_widget_cache' ) );
		add_action( 'deleted_post', array( &$this, 'flush_widget_cache' ) );
		add_action( 'switch_theme', array( &$this, 'flush_widget_cache' ) );
	}

	function widget( $args, $instance ) {
		$cache = wp_cache_get( 'widget_popular_ideas', 'widget' );

		if ( ! is_array( $cache ) )
			$cache = array();

		if ( ! isset( $args['widget_id'] ) )
			$args['widget_id'] = $this->id;

		if ( isset( $cache[ $args['widget_id'] ] ) ) {
			echo $cache[ $args['widget_id'] ];
			return;
		}

		ob_start();
		extract( $args );

		$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? __( 'Popular Ideas', APP_TD ) : $instance['title'], $instance, $this->id_base );
		if ( empty( $instance['number'] ) || ! $number = absint( $instance['number'] ) )
			$number = 10;

		$r = new WP_Query( array( 'post_type' => IDEAX_PTYPE, 'posts_per_page' => $number, 'no_found_rows' => true, 'post_status' => 'publish', 'ignore_sticky_posts' => true, 'orderby' => 'comment_count' ) );
		if ( $r->have_posts() ) :
		?>
			<?php echo $before_widget; ?>
			<?php if ( $title ) echo $before_title . $title . $after_title; ?>
			<div class="widget-content">
			<?php while ( $r->have_posts() ) : $r->the_post(); ?>
				<div class="widget-idea">
					<?php the_author_gravatar(); ?>
					<div class="widget-idea-body clear">
						<h4><a href="<?php the_permalink() ?>" title="<?php echo esc_attr( get_the_title() ? get_the_title() : get_the_ID() ); ?>"><?php if ( get_the_title() ) the_title(); else the_ID(); ?></a></h4>
						<div class="widget-idea-author"><?php the_idea_author(); ?></div>
						<div class="widget-listing-category">
							<span class="category"><?php the_idea_category(); ?></span> / <span class="status open"><?php the_idea_status(); ?></span>
						</div><!-- /.listing-category -->
					</div><!-- /.widget-idea-body -->
				</div><!-- /.widget-idea -->
			<?php endwhile; ?>
			</div>
			<?php echo $after_widget; ?>
		<?php
			// Reset the global $the_post as this query will have stomped on it
			wp_reset_postdata();

		endif;

		$cache[ $args['widget_id'] ] = ob_get_flush();
		wp_cache_set( 'ideax_widget_popular_ideas', $cache, 'widget' );
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['number'] = (int) $new_instance['number'];
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset( $alloptions['ideax_widget_popular_ideas'] ) )
			delete_option( 'ideax_widget_popular_ideas' );

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete( 'ideax_widget_popular_ideas', 'widget' );
	}

	function form( $instance ) {
		$title = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$number = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
?>
		<p><label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', APP_TD ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" /></p>

		<p><label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of ideas to show:', APP_TD ); ?></label>
		<input id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="text" value="<?php echo $number; ?>" size="3" /></p>
<?php
	}
}

class IDEAX_Widget_Recent_Comments extends WP_Widget {

	function __construct() {
		$widget_ops = array(
			'description' => __( 'The most recent responses', APP_TD ),
			'classname' => 'widget_recent-comments clear'
		);
		parent::__construct( 'ideax-recent-comments', __( 'Ideas Theme - Recent Responses', APP_TD ), $widget_ops );

		$this->alt_option_name = 'ideax_widget_recent_comments';

		add_action( 'comment_post', array( &$this, 'flush_widget_cache' ) );
		add_action( 'transition_comment_status', array( &$this, 'flush_widget_cache' ) );
	}

	function flush_widget_cache() {
		wp_cache_delete( 'ideax_widget_recent_comments', 'widget' );
	}

	function widget( $args, $instance ) {

		$cache = wp_cache_get( 'ideax_widget_recent_comments', 'widget' );

		if ( ! is_array( $cache ) )
			$cache = array();

		if ( isset( $cache[ $args['widget_id'] ] ) ) {
			echo $cache[ $args['widget_id'] ];
			return;
		}

		ob_start();
		extract( $args, EXTR_SKIP );

		$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? __( 'Recent Responses', APP_TD ) : $instance['title'] );
		$number = empty( $instance['number'] ) ? '5' : $instance['number'];

		$comments = get_comments( array(
			'number'  => $number,
			'status'  => 'approve',
			'post_status' => 'publish',
			'post_type' => IDEAX_PTYPE
		) );

		echo $before_widget;

		if ( $title ) echo $before_title . $title . $after_title;

		if ( $comments ) {
		?>
			<div class="widget-content">
			<?php
				foreach ( (array) $comments as $comment ) {
					if ( ! $comment->user_id ) continue;
					$user = get_userdata( $comment->user_id );
			?>
					<div class="widget-idea">
						<?php echo html_link( get_permalink( $comment->comment_post_ID ) , get_avatar( $user->ID, 32 ) ); ?>
						<div class="widget-idea-body clear">
							<h4><?php echo html_link( get_permalink( $comment->comment_post_ID ), get_the_title( $comment->comment_post_ID ) ); ?></h4>
							<div class="widget-idea-author"><?php the_idea_author( $user->ID ); ?></div>
							<div class="widget-comment">
								<span><?php echo ideax_truncate( $comment->comment_content, 120, '', " " ) ; ?></span>
							</div><!-- /.widget-comment -->
						</div><!-- /.widget-idea-body -->
					</div><!-- /.widget-idea -->
			<?php
				}
			?>
			</div>
		<?php

		} else {
		?>
			<div class="widget-content">
				<p><?php _e( 'No comments yet', APP_TD ); ?></p>
			</div>
    <?php
		}
		echo $after_widget;

		$cache[ $args['widget_id'] ] = ob_get_flush();
		wp_cache_set( 'ideax_widget_recent_comments', $cache, 'widget' );
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['number'] = absint( $new_instance['number'] );
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset( $alloptions['ideax_widget_recent_comments'] ) )
			delete_option( 'ideax_widget_recent_comments' );

		return $instance;
	}

	function form( $instance ) {
		$title = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$number = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
    ?>
		<p><label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', APP_TD ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" /></p>

		<p><label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of comments to show:', APP_TD ); ?></label>
		<input id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="text" value="<?php echo $number; ?>" size="3" /></p>
<?php
	}
}

//widget_stat-counter cursive
class IDEAX_Widget_Quick_Info extends WP_Widget {

	function __construct() {
		$widget_ops = array(
			'description' => __( "Usable only on the 'Single Idea' sidebar.", APP_TD ),
			'classname' => 'widget_ideas-info'
		);

		parent::__construct( 'ideax-quick-info', __( 'Ideas Theme - Quick Info', APP_TD ), $widget_ops );
	}

	function widget( $args, $instance ) {
		global $ideax_options;

		if ( ! is_singular(IDEAX_PTYPE) )
			return;

		extract( $args );

		$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? __( 'Quick Info', APP_TD ) : $instance['title'], $instance, $this->id_base );

		echo $before_widget;

		if ( $title ) echo $before_title . $title . $after_title;
?>
		<div class="widget-content">
			<ul>
				<li><?php _e( 'Idea Added', APP_TD ); ?><span class="fr"><?php printf( __( '%s ago', APP_TD ), idea_get_idea_time() ); ?></span></li>
				<li><?php _e( 'Last updated', APP_TD ); ?> <span class="fr"><?php printf( __( '%s ago', APP_TD ), idea_get_idea_modified_time() ); ?></span></li>
				<li><?php _e( 'Responses', APP_TD ); ?> <span class="fr"><?php the_responses(); ?></span></li>
				<li><?php _e( 'Status', APP_TD ); ?><span class="fr"><?php the_idea_status(); ?></span></li> 
			</ul>
		</div>
<?php
		echo $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );

		return $instance;
	}

	function form( $instance ) {
		//Defaults
		$instance = wp_parse_args( (array) $instance, array( 'title' => '' ) );
		$title = esc_attr( $instance['title'] );
?>
		<p><label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', APP_TD ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" /></p>
<?php
	}
}

class IDEAX_Widget_Voters extends WP_Widget {

	function __construct() {
		$widget_ops = array(
			'description' => __( "Usable only on the 'Single Idea' sidebar.", APP_TD ),
			'classname' => 'widget_votes'
		);
		parent::__construct( 'ideax-votes', __( 'Ideas Theme - Voters', APP_TD ), $widget_ops );
	}

	function widget( $args, $instance ) {

		if ( ! is_singular( IDEAX_PTYPE ) )
		    return;

		extract( $args );

		$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? __( 'Voters', APP_TD ) : $instance['title'], $instance, $this->id_base );
		$number = empty( $instance['number'] ) ? '9999' : $instance['number'];

		echo $before_widget;

		if ( $title ) echo $before_title . $title . $after_title;

		echo ideax_widget_show_voters( $number );

		echo $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['number'] = absint( $new_instance['number'] );

		return $instance;
	}

	function form( $instance ) {
		$title = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$number = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
?>
		<p><label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', APP_TD ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" /></p>

		<p><label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of user votes to show:', APP_TD ); ?></label>
		<input id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="text" value="<?php echo $number; ?>" size="3" /></p>
<?php
	}
}
